@@ -1,7 +1,7 @@
 ;;; yatexadd.el --- YaTeX add-in functions -*- coding: sjis -*-
-;;; (c)1991-2019 by HIROSE Yuuji.[yuuji@yatex.org]
-;;; Last modified Thu Oct 17 09:44:48 2019 on firestorm
-;;; $Id: yatexadd.el,v 777d17c07759 2019-10-17 09:52 +0900 yuuji $
+;;; (c)1991-2022 by HIROSE Yuuji.[yuuji@yatex.org]
+;;; Last modified Sun Nov 24 21:01:58 2024 on firestorm
+;;; $Id: yatexadd.el,v f039d15cdba8 2024-11-24 21:04 +0900 yuuji $
 
 ;;; Code:
 ;;;
@@ -193,15 +193,22 @@ YaTeX-make-begin-end."
 
 
 ;; wrapfig.sty
-(defun YaTeX:wrapfigure ()
-  (YaTeX-help "wrapfigure")
-  (concat
-   (let ((lines (YaTeX-read-string-or-skip "Wrap Lines(Optional): ")))
-     (if (string< "" lines)
-	 (concat "[" lines "]")))
-   "{" (YaTeX:read-oneof "rlioRLIO" t) "}"
-   "{" (YaTeX:read-length "Image width: ") "}"))
- 
+(defun YaTeX:wrapfigure (&optional kind)
+  (setq kind (or kind "figure"))
+  (YaTeX-help (concat "wrap" kind))
+  (prog1
+      (concat
+       (let ((lines (YaTeX-read-string-or-skip "Wrap Lines(Optional): ")))
+	 (if (string< "" lines)
+	     (concat "[" lines "]")))
+       "{" (YaTeX:read-oneof "rlioRLIO" t) "}"
+       "{" (YaTeX:read-length (concat (capitalize kind) " width: ")) "}")
+    (setq YaTeX-section-name "includegraphics")))
+
+(defun YaTeX:wraptable ()
+  (prog1
+      (YaTeX:wrapfigure "table")
+    (setq YaTeX-env-name "tabular")))
 
 ;;;
 ;;Sample functions for section-type command.
@@ -306,6 +313,11 @@ YaTeX-make-begin-end."
 (defun YaTeX:itembox ()
   (concat "{" (YaTeX-read-string-or-skip "Item heading string: ") "}"))
 
+(defun YaTeX:spacing ()
+  (concat "{" (read-string-with-history "Line spacing by: ") "}"))
+(defun YaTeX::setstretch (argp)
+  (read-string-with-history "Page global Line stretch factor: "))
+
 ;;;
 ;;Sample functions for maketitle-type command.
 ;;;
@@ -1843,6 +1855,7 @@ and print them to standard output."
     ("oneside") ("twoside") ("draft") ("final") ("leqno") ("fleqn") ("openbib")
     ("tombow") ("titlepage") ("notitlepage") ("dvips")
     ("mingoth")				;for jsarticle
+    ("uplatex")				;for uplatex
     ("clock")				;for slides class only
     )
     "Default options list for documentclass")
@@ -1880,7 +1893,9 @@ and print them to standard output."
 
 (defvar YaTeX:documentclasses-default
   '(("article") ("jarticle") ("report") ("jreport") ("book") ("jbook")
-    ("jsarticle") ("jsbook")
+    ("ltjsarticle") ("ltjsreport") ("ltjsbook")
+    ("ltjarticle") ("ltjreport") ("ltjbook")
+    ("jsarticle") ("jsreport") ("jsbook")
     ("j-article") ("j-report") ("j-book")
     ("letter") ("slides") ("ltxdoc") ("ltxguide") ("ltnews") ("proc"))
   "Default documentclass alist")
@@ -1981,6 +1996,48 @@ and print them to standard output."
    ((= argp 2) (YaTeX::color-completing-read "Inner color: "))
    ((= argp 3) (YaTeX-read-string-or-skip "Colored string: "))))
 
+(defun YaTeX:columncolor ()
+  (let ((model (YaTeX-completing-read-or-skip
+		"Color model: " '(("rgb") ("gray") ("named")))))
+    (put 'YaTeX:columncolor 'model model)
+    (if (string= "" model) "" (concat "[" model "]"))))
+
+(fset 'YaTeX:rowcolor 'YaTeX:columncolor)
+(fset 'YaTeX:cellcolor 'YaTeX:columncolor)
+
+(defun YaTeX::columncolor (argp)
+  (let ((model (get 'YaTeX:columncolor 'model))
+	(type (cond ((string-match "column" YaTeX-section-name) "Column")
+		    ((string-match "row" YaTeX-section-name) "Row")
+		    ((string-match "cell" YaTeX-section-name) "Cell")
+		    (t "Table")))
+	(last (get 'YaTeX::columncolor 'last-color))
+	str)
+    (put 'YaTeX::columncolor 'last-color
+	 (cond
+	  ((equal model "rgb")
+	   (setq str (YaTeX-read-string-or-skip
+		      "R, G, B values: "
+		      (cons (or last "0.6, 0.8, 0.9") 0)))
+	   (cond
+	    ((string-match ",.*," str) str)
+	    ((string-match "\\(\\S +\\)\\s +\\(\\S +\\)\\s +\\(\\S +\\)" str)
+	     (format "%s, %s, %s" (YaTeX-match-string 1 1 str)
+		     (YaTeX-match-string 2 2 str)(YaTeX-match-string 3 3 str)))
+	    (t (message "%s may cause error on typesetting" str)
+	       str)))
+	  ((equal model "gray")
+	   (setq str (YaTeX-read-string-or-skip "Grayscale values(0.0 - 1.0): "))
+	   (if (<= (string-to-number str) 1)
+	       str
+	     (message "%s may be an error.  Values from 0.0 to 1.0 are acceptable")
+	     str))
+	  ((equal model "named")
+	   (YaTeX::color-completing-read (concat type " color")))
+	  ))))
+(fset 'YaTeX::rowcolor 'YaTeX::columncolor)
+(fset 'YaTeX::cellcolor 'YaTeX::columncolor)
+
 (defun YaTeX:scalebox ()
   "Add-in for \\scalebox"
   (let ((vmag (YaTeX-read-string-or-skip (if YaTeX-japan "{(Ŕ]): "
@@ -2044,7 +2101,8 @@ and print them to standard output."
     (if (string= "" str) ""
       (concat "[" str "]"))))
 
-(defvar YaTeX::get-boundingbox-cmd YaTeX-cmd-gs
+(defvar YaTeX::get-boundingbox-cmd
+  (or (YaTeX-executable-find "extractbb") YaTeX-cmd-gs)
   "Command to get bounding box from PDF files.
 Possible values are `gs' and `extractbb'.")
 
@@ -2078,7 +2136,7 @@ This function relies on gs(ghostscript) command installed."
 	 (or (fboundp 'yahtml-get-image-info)
 	     (progn
 	       (load "yahtml" t) (featurep 'yahtml))) ;(require 'yahtml nil t)
-	 (if (string-match "\\.pdf" imgfile)
+	 (if (string-match "\\.\\(pdf\\|png\\)" imgfile)
 	     (and
 	      (setq info (YaTeX::get-boundingbox imgfilepath))
 	      (stringp info)
@@ -2196,6 +2254,21 @@ This function relies on gs(ghostscript) command installed."
        ((memq c '(?c ?C)) (setq left "{\\scriptsize " right "}")))
       (format "%s%s%s" left char right)))))
 
+
+;;; -------------------- booktab staff --------------------
+(defun YaTeX::toprule (argp)
+  (if (equal argp 1) (YaTeX:read-length "Top Rule Width: ")))
+(defun YaTeX::midrule (argp)
+  (if (equal argp 1) (YaTeX:read-length "Middle Rule Width: ")))
+(defun YaTeX::cmidrule (argp)
+  (if (equal argp 1) (YaTeX:read-length "Inter-Columns Rule Width: ")))
+(defun YaTeX::bottomrule (argp)
+  (if (equal argp 1) (YaTeX:read-length "Bottom Rule Width: ")))
+(defun YaTeX::addlinespace (argp)
+  (if (equal argp 1) (YaTeX:read-length "Additional Line space: ")))
+(defun YaTeX::specialrule (argp)
+  (if (equal argp 1) (YaTeX:read-length "Special rule: ")))
+
 ;;; -------------------- beamer stuff --------------------
 (defvar YaTeX:frame-option-alist-default
   '(("plain") ("containsverbatim") ("shrink") ("squeeze")
@@ -2275,6 +2348,28 @@ This function relies on gs(ghostscript) command installed."
     (if (string< "" opt)
 	(concat "[" opt "]"))))
 
+;;; -------------------- moreverb stuff --------------------
+;;; http://xyoshiki.web.fc2.com/tex/moreverb.html
+(defun YaTeX:verbatimtab ()
+  (let ((width (YaTeX-read-string-or-skip "Tab width: ")))
+    (if (string< "" width)
+	(concat "[" width "]"))))
+(fset 'YaTeX:verbatimtabinput 'YaTeX:verbatimtab)
+(defun YaTeX::verbatimtabinput (argp)
+  (cond
+   ((= argp 1)
+    (YaTeX::include 1))))
+(defun YaTeX:listinginput()
+  (let ((interval (YaTeX-read-string-or-skip "Listing internavl: ")))
+    (if (string< "" interval)
+	(concat "[" interval "]"))))
+(defun YaTeX::listinginput (argp)
+  (cond
+   ((= argp 1)
+    (let ((int (YaTeX-read-string-or-skip "Start Line: " "1")))
+      (if (string< "" int) int "1")))
+   ((= argp 2) (YaTeX::verbatimtabinput 1))))
+
 ;;; -------------------- math-mode stuff --------------------
 (defun YaTeX::tilde (&optional pos)
   "For accent macros in mathmode"
