@@ -1,8 +1,8 @@
 ;;; yatexprc.el --- YaTeX process handler -*- coding: sjis -*-
 ;;; 
-;;; (c)1993-2019 by HIROSE Yuuji.[yuuji@yatex.org]
-;;; Last modified Thu Dec 26 12:48:12 2019 on firestorm
-;;; $Id: yatexprc.el,v 4dad5f91b26c 2019-12-26 12:50 +0859 yuuji $
+;;; (c)1993-2022 by HIROSE Yuuji.[yuuji@yatex.org]
+;;; Last modified Thu Dec  1 19:13:20 2022 on firestorm
+;;; $Id: yatexprc.el,v 5aa2610bd397 2022-12-25 14:12 +0900 yuuji $
 
 ;;; Code:
 ;(require 'yatex)
@@ -39,7 +39,8 @@
   (cond
    (YaTeX-dos (cdr (assq 1 YaTeX-kanji-code-alist)))
    (YaTeX-emacs-20
-    (cdr (assoc latex-message-kanji-code YaTeX-kanji-code-alist)))
+    (let ((sym (cdr (assoc latex-message-kanji-code YaTeX-kanji-code-alist))))
+      (if (eq sym 'no-conversion) 'undecided sym)))
    ((boundp 'MULE)
     (symbol-value
      (cdr (assoc latex-message-kanji-code YaTeX-kanji-code-alist))))
@@ -183,7 +184,8 @@ thus, it call bibtex only if warning messages about citation are seen.")
 		(ppprop (get 'YaTeX-typeset-process 'ppcmd))
 		(ppcmd (cdr (assq proc ppprop)))
 		(bcprop (get 'YaTeX-typeset-process 'bibcmd))
-		(bibcmd (cdr (assq proc bcprop))))
+		(bibcmd (cdr (assq proc bcprop)))
+		(useluatex (string-match "lua.*tex" thiscmd)))
 	   (put 'YaTeX-typeset-process 'ppcmd ;erase ppcmd
 		(delq (assq proc ppprop) ppprop))
 	   (put 'YaTeX-typeset-process 'bibcmd ;erase bibcmd
@@ -285,8 +287,14 @@ thus, it call bibtex only if warning messages about citation are seen.")
 		     ;; If ppcmd is set and it is a function symbol,
 		     ;; call it whenever command succeeded or not
 		     (funcall ppcmd))
-		    ((and ppcmd (string-match "finish" mes))
-		     (insert (format "=======> Success! Calling %s\n" ppcmd))
+		    ((and ppcmd (string-match "finish" mes)
+			  ;; It is bad way to detect the necessity of
+			  ;; pdf-conversion by seeing typesetter name because
+			  ;; new typesetter other than lua(la)tex might come.
+			  ;; More reasonable way is to determine by the
+			  ;; existence of PDF file.
+			  (not useluatex))
+		     (insert (format "=======>  Success! Calling %s\n" ppcmd))
 		     (setq mode-name	; set process name
 			   (concat
 			    mode-name "+"
@@ -1149,6 +1157,37 @@ by region."
 	  t)				;for YaTeX-goto-corresponding-*
       nil)))
 
+(and (or (featurep 'dbus) (load "dbus" t))
+     ;; Cannot load dbus on emacs without dbus module
+     (fboundp 'url-unhex-string)
+     (fboundp 'dbus-register-signal)
+     ;; From https://texwiki.texjp.org/?Emacs#vecb4fd9
+     (progn
+       (fset 'YaTeX-evince-inverse-search
+	     (if (fboundp 'evince-inverse)
+		 'evince-inverse	;Use previously defined one
+	       (function
+		(lambda (file linecol &rest args)
+		  (let* ((fn (decode-coding-string
+			      (url-unhex-string
+			       (if (string-match "^file:///" file)
+				   (substring file 7) file))
+			      'utf-8))
+			 (buf (YaTeX-switch-to-buffer fn))
+			 (ln  (car linecol))
+			 (col (car (cdr linecol))))
+		    (if (null buf)
+			(error "[Synctex]: Not found [%s]" file)
+		      (goto-line ln)
+		      (move-to-column (max 0 col))))))))
+       (condition-case ()
+	   (dbus-register-signal
+	    :session nil "/org/gnome/evince/Window/0"
+	    "org.gnome.evince.Window" "SyncSource"
+            'YaTeX-evince-inverse-search)
+	 (error
+	  (message "Reverse search not available on this system.")))))
+
 (defun YaTeX-set-virtual-error-position (file-sym line-sym)
   "Replace the value of FILE-SYM, LINE-SYM by virtual error position."
   (cond
